@@ -151,9 +151,16 @@ def amazon():
 
 
 def msrank():
+    url = 'https://storage.mds.yandex.net/get-devtools-opensource/233854/msrank.tar.gz'
+    md5 = '34fee225d02419adc106581f4eb36f2e'
+    dataset_name, train_file, test_file = 'msrank', 'train.tsv', 'test.tsv'
+    return _load_dataset_pd(url, md5, dataset_name, train_file, test_file, header=None, sep='\t', cache=True)
+
+
+def msrank_10k():
     url = 'https://storage.mds.yandex.net/get-devtools-opensource/250854/msrank_10k.tar.gz'
     md5 = '79c5b67397289c4c8b367c1f34629eae'
-    dataset_name, train_file, test_file = 'msrank', 'train.csv', 'test.csv'
+    dataset_name, train_file, test_file = 'msrank_10k', 'train.csv', 'test.csv'
     return _load_dataset_pd(url, md5, dataset_name, train_file, test_file, header=None)
 
 
@@ -294,3 +301,22 @@ def adult():
     test_df = test_df.astype(dtype)
 
     return train_df, test_df
+
+
+def higgs():
+    """
+    Download "higgs" [1] data set.
+
+    Will return two pandas.DataFrame-s, first with train part and second with
+    test part of the dataset. Object class will be located in the first
+    column of dataset.
+
+    [1]: https://archive.ics.uci.edu/ml/datasets/HIGGS
+    """
+    url = 'https://storage.mds.yandex.net/get-devtools-opensource/250854/higgs.tar.gz'
+    md5 = 'ad59ba8328a9afa3837d7bf1a0e10e7b'
+    dataset_name, train_file, test_file = 'higgs', 'train.tsv', 'test.tsv'
+    train_path, test_path = _download_dataset(url, md5, dataset_name, train_file, test_file, cache=True)
+    return (
+        _load_numeric_only_dataset(train_path, 10500000, 29, sep='\t'),
+        _load_numeric_only_dataset(test_path, 500000, 29, sep='\t'))
